def select(composer):
    #the base feature is implicitely activated, 
    #because it is imported and called from variant runner
    #
    pass
